@@ -55,7 +55,7 @@ class clip:
 		self.video_fade_amount = 2.0
 		self.parent = parent_track	  # the parent track this clip lives on
 		self.file_object = file_object  # the file object that this clip is linked to
-		self.unique_id = str(uuid.uuid1())	
+		self.unique_id = str(uuid.uuid1())
 		
 		# init key-frame dictionary
 		self.keyframes = {"start" : keyframe(0, 100.0, 100.0, 0.0, 0.0, 1.0),
@@ -86,13 +86,6 @@ class clip:
 		# Add an effect (and it's default params) to the effect list
 		# Only add an effect if it's not already on the clip
 
-		# loop through clip's effects
-		for my_effect in self.effects:
-			# is effect already here?
-			if my_effect.service == service:
-				print "ALREADY HAS EFFECT... EXITING"
-				return
-
 		# Get list of effects
 		my_effects = self.parent.parent.project.form.effect_list
 		
@@ -108,25 +101,27 @@ class clip:
 				
 				# ADD EFFECT TO CLIP
 				self.effects.append(new_effect)
+				self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Added effect") + " " + service)
+
 	
-	def Remove_Effect(self, service):
+	def Remove_Effect(self, unique_id):
 		# Remove an effect from the list
 		
 		# loop through clip's effects
 		for my_effect in self.effects:
 			# is effect already here?
-			if my_effect.service == service or my_effect.service + ":" + my_effect.audio_effect == service:
+			if my_effect.unique_id == unique_id:
 				# remove from list
 				self.effects.remove(my_effect)
 				return
 
-	def Move_Effect(self, service, direction):
+	def Move_Effect(self, unique_id, direction):
 		# Move an effect UP or Down (if possible)
 		
 		# loop through clip's effects
 		for my_effect in self.effects:
 			# is effect already here?
-			if my_effect.service == service or my_effect.service + ":" + my_effect.audio_effect == service:
+			if my_effect.unique_id == unique_id:
 				# get index of item
 				my_index = self.effects.index(my_effect)
 				
@@ -191,10 +186,8 @@ class clip:
 		parent_sequence = self.parent.parent
 		bg_track = track.track("Background Track", parent_sequence)
 		bg_track.parent = parent_sequence
-		#bg_end_time = parent_sequence.Calculate_Length()
 		bg_image = files.OpenShotFile(project)
 		bg_image.name = os.path.join(project.IMAGE_DIR, "black.png")
-		#bg_image.length = bg_end_time
 		bg_image.length = self.length()
 		bg_image.max_frames = round(bg_image.length * fps)
 		bg_clip = clip("Background Clip", "Gold", 0.0, 0.0, bg_image.length, bg_track, bg_image)
@@ -203,7 +196,7 @@ class clip:
 		bg_track.clips.append(bg_clip)
 		
 		# add XML for background track
-		bg_track.GenerateXML(dom, multitrack)
+		bg_track.GenerateXML(dom, multitrack, fps=fps)
 		
 		#### TRACK XML ####
 		#### needs to have the same # of the tracks as the real project ####
@@ -216,7 +209,7 @@ class clip:
 
 			#### CLIP XML ####
 			if self.parent == MyTrack:
-				self.GenerateXML(dom, playlist, current_frame=0, preview_mode=True)
+				self.GenerateXML(dom, playlist, current_frame=0, preview_mode=True, fps=fps)
 		
 		# Save the XML dom
 		f = open(file_name, "w")
@@ -224,13 +217,12 @@ class clip:
 		f.close()
 	 
 	 
-	def GenerateXML(self, dom, xmlParentNode, current_frame=0, preview_mode=False):
+	def GenerateXML(self, dom, xmlParentNode, current_frame=0, preview_mode=False, fps=None):
 
 		# get the project
 		project = self.parent.parent.project
 
-		# get the frames per second (from the project)
-		fps = project.fps()
+		# init the frame offset
 		frame_offset = 0
 		
 		# calculate what the new frame number is (and the size of the gap from the previous clip)
@@ -274,11 +266,6 @@ class clip:
 
 		# determine length of this clip
 		ending_frame = current_frame + (out_frame_number - in_frame_number)
-		#ending_frame = ending_frame - frame_offset
-
-		#print "ending_frame: %s" % ending_frame
-		#print "... calc position: %s" % round(self.position_on_track * fps)
-		#print "... calc end: %s" % round((self.position_on_track + self.length()) * fps)
 
 		# create the clip producer node
 		producer = dom.createElement("producer")
@@ -348,8 +335,8 @@ class clip:
 			
 			# create colour producer
 			property = dom.createElement("property")
-			property.setAttribute("name", "resource")
-			text = dom.createTextNode(resource_name)
+			property.setAttribute("name", "mlt_service")
+			text = dom.createTextNode("color")
 			property.appendChild(text)
 			producer.appendChild(property)
 
@@ -357,29 +344,12 @@ class clip:
 		############################
 		# Add VOLUME filter
 		############################
-	
-		# Get clip index.  Subtract this from the IN / OUT frame.  This is
-		# to correct a problem with the blank space (in the XML) getting offset from the composites
-		# for some reason.  Not really sure, but this seems to fix it. =)
-		#clip_index = self.parent.clips.index(self) + 1
-	
-		# get the IN / OUT frame for the Transistion (absolute frame # of the project)
-		#trans_in_frame_number = round(self.position_on_track * fps) - 1 # + clip_index
-		#trans_out_frame_number = trans_in_frame_number + round(self.length() * fps) #+ clip_index
 		
 		# determine all COMPOSITES that are needed
-		#trans_in_frame_number = round(self.position_on_track * fps)
-		#trans_out_frame_number = round((self.position_on_track + self.length()) * fps)
 		trans_in_frame_number = current_frame
 		trans_out_frame_number = ending_frame
-		
-		# don't allow 0 frame
-		#if trans_in_frame_number <= 0:
-		#	trans_in_frame_number = 1
-			
 		current_audio_frame = trans_in_frame_number
 		
-		
 		if self.play_audio == False or self.parent.play_audio == False:
 			# MUTE
 			filter = dom.createElement("filter")
@@ -476,13 +446,12 @@ class clip:
 			##############################
 			#         COMPOSITE
 			#############################
-			self.GenerateComposites(dom, current_frame, ending_frame, preview_mode)
+			self.GenerateComposites(dom, current_frame, ending_frame, preview_mode, fps=fps)
 
 			
 			##############################
 			#			 MIX
 			##############################
-			
 			transition = dom.createElement("transition")
 			transition.setAttribute("in", str(trans_in_frame_number))
 			transition.setAttribute("out", str(trans_out_frame_number))
@@ -521,16 +490,13 @@ class clip:
 			# add composite transition to tractor
 			tractor_node.appendChild(transition)
 			
-			# return # of frames for this clip
-			return ending_frame
+		# return # of frames for this clip
+		return ending_frame
 			
 
-	def GenerateComposites(self, dom, in_current_frame, in_ending_frame, preview_mode=False):
+	def GenerateComposites(self, dom, in_current_frame, in_ending_frame, preview_mode=False, fps=None):
 		# get the project
 		project = self.parent.parent.project
-
-		# get the frames per second (from the project)
-		fps = project.fps()
 		
 		overlapping_transitions = []
 		has_left = None
@@ -558,15 +524,13 @@ class clip:
 						has_entire = t
 				
 		# determine all COMPOSITES that are needed
-		#current_frame = round(self.position_on_track * fps)
-		#end_frame = round((self.position_on_track + self.length()) * fps)
 		current_frame = in_current_frame 
 		end_frame = in_ending_frame
 		
 		### IF ENTIRE CLIP IS OVERLAPPED, ADD JUST 1 TRANSITION
 		if has_entire:
 			# add just 1 transition (which is the length of the clip)
-			self.CreateCompositeXML(dom, current_frame, end_frame, "entire", has_entire)
+			self.CreateCompositeXML(dom, current_frame, end_frame, "entire", has_entire, fps=fps)
 			
 		else:
 			# NOT OVERLAPPING THE ENTIRE CLIP
@@ -574,14 +538,14 @@ class clip:
 			if has_left:
 				# LEFT TRANSITION
 				end = round((has_left.position_on_track + has_left.length) * fps)
-				self.CreateCompositeXML(dom, current_frame, end, "left", has_left)
+				self.CreateCompositeXML(dom, current_frame, end, "left", has_left, fps=fps)
 				current_frame = end
 			elif self.video_fade_in:
 				# LEFT FADE IN
 				end = current_frame + round((self.video_fade_amount) * fps)
 				if end > end_frame:
 					end = end_frame
-				self.CreateCompositeXML(dom, current_frame, end, "fade in")
+				self.CreateCompositeXML(dom, current_frame, end, "fade in", fps=fps)
 				current_frame = end
 	
 				
@@ -594,12 +558,12 @@ class clip:
 				
 				if current_frame < trans_begin_frame:
 					# add filler
-					self.CreateCompositeXML(dom, current_frame, trans_begin_frame, "filler")
+					self.CreateCompositeXML(dom, current_frame, trans_begin_frame, "filler", fps=fps)
 				
 				# add transition
 				current_frame = trans_begin_frame
 				end = trans_end_frame
-				self.CreateCompositeXML(dom, current_frame, end, "inside", t)
+				self.CreateCompositeXML(dom, current_frame, end, "inside", t, fps=fps)
 				current_frame = end
 	
 	
@@ -612,12 +576,12 @@ class clip:
 				
 				if current_frame < trans_begin_frame:
 					# add filler
-					self.CreateCompositeXML(dom, current_frame, trans_begin_frame, "filler")
+					self.CreateCompositeXML(dom, current_frame, trans_begin_frame, "filler", fps=fps)
 	
 				# add transition
 				current_frame = trans_begin_frame
 				end = end_frame
-				self.CreateCompositeXML(dom, current_frame, end, "right", has_right)
+				self.CreateCompositeXML(dom, current_frame, end, "right", has_right, fps=fps)
 				current_frame = end
 	
 			elif self.video_fade_out:
@@ -625,47 +589,49 @@ class clip:
 				begin_of_fade_out = end_frame - round(self.video_fade_amount * fps)
 				if current_frame < begin_of_fade_out:
 					# add filler
-					self.CreateCompositeXML(dom, current_frame, begin_of_fade_out, "filler")
+					self.CreateCompositeXML(dom, current_frame, begin_of_fade_out, "filler", fps=fps)
+				elif current_frame > begin_of_fade_out:
+					# shorten the fade (if needed)
+					begin_of_fade_out = current_frame
 				
 				current_frame = begin_of_fade_out
 				end = end_frame
-				self.CreateCompositeXML(dom, current_frame, end, "fade out")
+				self.CreateCompositeXML(dom, current_frame, end, "fade out", fps=fps)
 				current_frame = end
 				
 				
 			#### ADD FINAL FILLER, IF NEEDED ####
 			if current_frame < end_frame:
 				# add filler
-				self.CreateCompositeXML(dom, current_frame, end_frame, "filler")
+				self.CreateCompositeXML(dom, current_frame, end_frame, "filler", fps=fps)
 			
 			
-	def CreateCompositeXML(self, dom, current_frame, end_frame, comment, t = None):
-		
+	def CreateCompositeXML(self, dom, current_frame, end_frame, comment, t = None, fps = None):
+
 		# get the frames per second (from the project)
 		project = self.parent.parent.project
-		fps = project.fps()
-		
+
 		# dont' add composite for a "filler" (if requested)
 		if self.composite == False and comment == "filler":
 			return
+		
+		# get length and geometry key frames of clip (in frames)
+		clip_length_frames = self.length() * fps
+		kf_start = self.keyframes["start"]
+		kf_end = self.keyframes["end"]
 
-		h1, h2 = self.get_keyframe_values("height", current_frame, end_frame)
-		w1, w2 = self.get_keyframe_values("width", current_frame, end_frame)
-		x1, x2 = self.get_keyframe_values("x", current_frame, end_frame)
-		y1, y2 = self.get_keyframe_values("y", current_frame, end_frame)
-		a1, a2 = self.get_keyframe_values("alpha", current_frame, end_frame)
+		h1, h2 = self.get_keyframe_values("height", current_frame, end_frame, fps, clip_length_frames, kf_start, kf_end)
+		w1, w2 = self.get_keyframe_values("width", current_frame, end_frame, fps, clip_length_frames, kf_start, kf_end)
+		x1, x2 = self.get_keyframe_values("x", current_frame, end_frame, fps, clip_length_frames, kf_start, kf_end)
+		y1, y2 = self.get_keyframe_values("y", current_frame, end_frame, fps, clip_length_frames, kf_start, kf_end)
+		a1, a2 = self.get_keyframe_values("alpha", current_frame, end_frame, fps, clip_length_frames, kf_start, kf_end)
 
 		# get the root tractor node 
 		tractor_node = dom.getElementsByTagName("tractor")[0]
 		
-		# Get clip index.  Subtract this from the IN / OUT frame.  This is
-		# to correct a problem with the blank space (in the XML) getting offset from the composites
-		# for some reason.  Not really sure, but this seems to fix it. =)
-		#clip_index = self.parent.clips.index(self) + 1
-			
 		# get the IN / OUT frame for the Transistion (absolute frame # of the project)
-		trans_in_frame_number = current_frame #- clip_index
-		trans_out_frame_number = end_frame #- clip_index
+		trans_in_frame_number = current_frame
+		trans_out_frame_number = end_frame
 		
 		# Get the track index (i.e. track 0, 1, 2, 3, etc...)
 		if self.parent.name != "Background Track":
@@ -677,7 +643,6 @@ class clip:
 			track_index = len(self.parent.parent.tracks)
 			track_index_flipped = 0
 		
-		
 		transition = dom.createElement("transition")
 		transition.setAttribute("in", str(round(trans_in_frame_number)))
 		transition.setAttribute("out", str(round(trans_out_frame_number)))
@@ -700,6 +665,12 @@ class clip:
 		property.appendChild(text)
 		transition.appendChild(property)
 		
+		property = dom.createElement("property")
+		property.setAttribute("name", "progressive")
+		text = dom.createTextNode("1")
+		property.appendChild(text)
+		transition.appendChild(property)
+		
 		if t == None:
 			# NOT A TRANSITION
 			if comment == "fade in":
@@ -726,7 +697,6 @@ class clip:
 				a1 = t.mask_value / 100
 				a2 = t.mask_value / 100
 		
-		
 		geometry_start = "%d=%s%%,%s%%:%s%%x%s%%:%s; " % (0, locale.str(x1), locale.str(y1), locale.str(w1), locale.str(h1), locale.str(a1 * 100.0))
 		geometry_end = "%d=%s%%,%s%%:%s%%x%s%%:%s; " % (-1, locale.str(x2), locale.str(y2), locale.str(w2), locale.str(h2), locale.str(a2 * 100.0))
 		geometry = geometry_start + geometry_end
@@ -788,17 +758,10 @@ class clip:
 				
 				
 
-	def get_keyframe_values(self, prop_name, current_frame, end_frame):
+	def get_keyframe_values(self, prop_name, current_frame, end_frame, fps, clip_length_frames, kf_start, kf_end):
+		
 		# get the frames per second (from the project)
 		project = self.parent.parent.project
-		fps = project.fps()
-		
-		# get length of clip (in frames)
-		clip_length_frames = self.length() * fps
-		
-		# get geometry key frames (since they have to be calculated across many composites)
-		kf_start = self.keyframes["start"]
-		kf_end = self.keyframes["end"]
 		
 		if prop_name == "height":
 			prop_start = kf_start.height
@@ -921,7 +884,7 @@ class clip:
 			# canvas group is not passed in
 			# Get root group of the canvas
 			canvas_right = self.parent.parent.project.form.MyCanvas
-			root_right = canvas_right.get_root_item ()		
+			root_right = canvas_right.get_root_item ()
 			
 			# Create the Group (for the clip)
 			GroupClip = goocanvas.Group (parent = root_right)
@@ -1037,7 +1000,8 @@ class clip:
 					self.get_canvas_child(item, "clip_visible").set_properties(visibility = 1)
 					self.get_canvas_child(item, "clip_speaker").set_properties(visibility = 1)
 					#self.get_canvas_child(item, "clip_name").set_properties(visibility = 1)
-					
+					if self.effects:
+						self.get_canvas_child(item, "effect").set_properties(visibility = 1)
 					# raise the clip text (since it can get hidden by other clip-related layers)
 					self.get_canvas_child(item, "clip_name").raise_(None)
 					
@@ -1195,6 +1159,7 @@ class clip:
 				# Track the state of the hover over image
 				image5.set_data ("id", "clip_visible")
 				image5.connect ("button_press_event", self.on_visible_click)
+				image5.connect ("button_release_event", self.on_clip_buttons_release)
 				
 				# Get the track index (i.e. track 0, 1, 2, 3, etc...)
 				track_index = self.parent.parent.tracks.index(self.parent)
@@ -1238,6 +1203,7 @@ class clip:
 				# Track the state of the hover over image
 				image5.set_data ("id", "clip_speaker")
 				image5.connect ("button_press_event", self.on_audio_click)
+				image5.connect ("button_release_event", self.on_clip_buttons_release)
 				
 			else:
 				# get existing object
@@ -1247,6 +1213,40 @@ class clip:
 				existing_item.set_properties(x = x + 66)
 				existing_item.set_properties(visibility = 2)
 
+
+			# *** EFFECT IMAGE
+			if has_regular_images == False:
+			
+				# Load buttons
+				if self.effects:
+					imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/effect.png" % (self.parent.parent.project.form.openshot_path, theme))
+				
+				# Add Visible Image to Group
+					image5 = goocanvas.Image (parent = GroupClip,
+										  pixbuf = imgTrack_Visible.get_pixbuf(),
+										  x = x + 46,
+										  y = y + 36)  
+				
+					# Track the state of the hover over image
+					image5.set_data ("id", "effect")
+					image5.connect ("button_press_event", self.on_effect_click)
+				
+			else:
+				if self.effects:
+					try:				
+						# get existing object
+						existing_item = self.get_canvas_child(item, "effect")
+				
+						# resize existing canvas image object
+						existing_item.set_properties(x = x + 46)
+						existing_item.set_properties(visibility = 2)	
+					except:
+						pass
+	
+	
+	
+	
+	
 	
 				
 			# ///////////////////////////////////////////////////////
@@ -1500,7 +1500,7 @@ class clip:
 					self.show_preview = True
 
 					# re-load the xml (if not an audio file)
-					self.parent.parent.project.form.MyVideo.set_project(self.parent.parent.project, self.parent.parent.project.form, os.path.join(self.parent.parent.project.USER_DIR, "westley.xml"), mode="override", override_path=self.file_object.name)
+					self.parent.parent.project.form.MyVideo.set_project(self.parent.parent.project, self.parent.parent.project.form, os.path.join(self.parent.parent.project.USER_DIR, "sequence.mlt"), mode="override", override_path=self.file_object.name)
 					self.parent.parent.project.form.MyVideo.load_xml()
 					
 					# start and stop the video
@@ -1527,6 +1527,8 @@ class clip:
 					# change the cursor for the drag n drop operation
 					fleur = gtk.gdk.Cursor (gtk.gdk.FLEUR)
 					canvas = item.get_canvas ()
+					self.stored_x = item.get_bounds().x1
+					self.stored_y = item.get_bounds().y1
 					canvas.pointer_grab (item, gtk.gdk.POINTER_MOTION_MASK | gtk.gdk.BUTTON_RELEASE_MASK, fleur, event.time)
 
 			
@@ -1566,7 +1568,7 @@ class clip:
 
 		# re-load the xml (if not an audio file)
 		if (self.file_object.file_type == "video" or self.file_object.file_type == "image sequence") and self.speed == 1.0:
-			self.parent.parent.project.form.MyVideo.set_project(self.parent.parent.project, self.parent.parent.project.form, os.path.join(self.parent.parent.project.USER_DIR, "westley.xml"), mode="override", override_path=self.file_object.name)
+			self.parent.parent.project.form.MyVideo.set_project(self.parent.parent.project, self.parent.parent.project.form, os.path.join(self.parent.parent.project.USER_DIR, "sequence.mlt"), mode="override", override_path=self.file_object.name)
 			self.parent.parent.project.form.MyVideo.load_xml()
 			
 			# start and stop the video
@@ -1632,7 +1634,7 @@ class clip:
 		new_end_time = original_end_time
 
 		# Create the 2nd clip object
-		SecondClip = self.parent.AddClip(self.name, self.color, seconds_for_x, new_start_time, new_end_time, self.file_object)
+		SecondClip = self.parent.AddClip(self.name, self.color, seconds_for_x, new_start_time, new_end_time, self.file_object, record_to_history = None)
 		SecondClip.max_length = self.max_length
 		SecondClip.fill = self.fill
 		SecondClip.distort = self.distort
@@ -1658,7 +1660,7 @@ class clip:
 		self.parent.reorder_clips()
 		
 		# mark project as modified
-		self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True)
+		self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Sliced clip"))
 					
 
 	def get_snap_difference(self, clip_object, canvas_item):
@@ -1755,7 +1757,8 @@ class clip:
 
 	def on_button_release_x (self, item, target, event):
 		""" This method drops a clip, and snaps the clip to the nearest valid track """
-
+		
+		
 		# get reference to the canvas, and stop dragging the item
 		canvas = item.get_canvas()
 		canvas.pointer_ungrab (item, event.time)
@@ -1783,6 +1786,14 @@ class clip:
 			
 			# update clip's settings again (since the snapping could have moved them a bit)
 			self.update(item.get_bounds().x1, item.get_bounds().y1, drop_track)
+			
+			# check if clip has been really moved or not
+			if ((self.stored_x == item.get_bounds().x1) and (self.stored_y == item.get_bounds().y1)):
+				type_of_event = None
+			else:
+				type_of_event = _("Moved clip")
+			
+			self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = type_of_event)
 	
 			
 		elif isResize:
@@ -1797,6 +1808,7 @@ class clip:
 			
 			# switch video window back to 'view' mode (i.e. remove preview clip mode)
 			self.set_view_mode()
+			self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Resized clip"))
 				
 		# check if the timeline needs to be expanded
 		self.parent.parent.project.form.expand_timeline(self)
@@ -1856,10 +1868,9 @@ class clip:
 		
 		# get the parent left group
 		parent_group = item.get_parent()
+		canvas = parent_group.get_canvas()
+		canvas.pointer_ungrab (item, event.time)
 		
-		# mark project as modified
-		self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True)
-
 		if self.play_video == True:
 			# Load Hover Over
 			imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/not_visible_transparent.png" % (self.parent.parent.project.form.openshot_path, theme))
@@ -1876,6 +1887,9 @@ class clip:
 			# update play video variable
 			self.play_video = True
 
+		# mark project as modified
+		self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Changed visibility of clip"))
+
 		return False
 	
 	
@@ -1885,10 +1899,9 @@ class clip:
 		
 		# get the parent left group
 		parent_group = item.get_parent()
+		canvas = parent_group.get_canvas()
+		canvas.pointer_ungrab (item, event.time)
 		
-		# mark project as modified
-		self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True)
-
 		if self.play_audio == True:
 			# Load Hover Over
 			imgTrack_Visible = gtk.image_new_from_file("%s/openshot/themes/%s/speaker_mute_transparent.png" % (self.parent.parent.project.form.openshot_path, theme))
@@ -1905,8 +1918,20 @@ class clip:
 			# update play video variable
 			self.play_audio = True
 
+		# mark project as modified
+		self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = _("Changed audio of clip"))
+
 		return False
 	
+	def on_effect_click (self, item, target, event):
+		pass
+		#form1 = self.parent.parent.project.form
+		#from windows import ClipProperties
+		#form1.frmClipProperties = ClipProperties.frmClipProperties(form=form1, project=self.parent.parent.project, current_clip=self, current_clip_item=item)
+		#return True
+	
+	def on_clip_buttons_release(self, item, target, event):
+		return True
 		
 	#----------------------------------------------------------------------
 	def __setstate__(self, state):
