@@ -113,7 +113,7 @@ class OpenShotFolder:
 		self.items.append(newFolder)
 		
 		#set the modified status
-		self.project.set_project_modified(is_modified=True, refresh_xml=False)
+		self.project.set_project_modified(is_modified=True, refresh_xml=False, type=_("Added folder"))
 		
 		self.project.form.refresh()
 		
@@ -160,7 +160,7 @@ class OpenShotFolder:
 				self.items.append(newFile)
 
 		# mark project as modified
-		self.project.set_project_modified(is_modified=True, refresh_xml=False)
+		self.project.set_project_modified(is_modified=True, refresh_xml=False, type=_("Added file"))
 		
 		return newFile
 	
@@ -241,7 +241,7 @@ class OpenShotFolder:
 		item = self.FindFile(filename)
 		if item:
 			# mark project as modified
-			self.project.set_project_modified(is_modified=True, refresh_xml=True)
+			self.project.set_project_modified(is_modified=True, refresh_xml=True, type=_("Removed file"))
 			
 			# find clips that have this file object
 			for track in self.project.sequences[0].tracks:
@@ -330,7 +330,7 @@ class OpenShotFolder:
 			file.parent = folder_name
 			
 			# mark project as modified
-			self.project.set_project_modified(is_modified=True, refresh_xml=False)
+			self.project.set_project_modified(is_modified=True, refresh_xml=False, type=_("Moved to folder"))
 			
 	def RemoveParent(self, file_name, folder_name):
 		file = self.FindFile(file_name)
@@ -339,4 +339,4 @@ class OpenShotFolder:
 			file.parent = self.project.project_folder
 			
 			# mark project as modified
-			self.project.set_project_modified(is_modified=True, refresh_xml=False)
+			self.project.set_project_modified(is_modified=True, refresh_xml=False, type=_("Removed from folder"))
