@@ -24,7 +24,7 @@ from classes import files
 
 def save_project(project_object, file_path):
 		project = project_object
-	
+			
 		# create thumbnail folder (if it doesn't exist)
 		if os.path.exists(os.path.join(project_object.folder, "thumbnail")) == False:
 			# create new thumbnail folder
@@ -59,16 +59,24 @@ def save_project(project_object, file_path):
 		old_ruler_time = project_object.sequences[0].ruler_time
 		old_play_head_line = project_object.sequences[0].play_head_line
 		old_thumbnailer = project_object.thumbnailer
+		project_object.mlt_profile = None
 		
 		project_object.sequences[0].play_head = None
 		project_object.sequences[0].ruler_time = None
 		project_object.sequences[0].play_head_line = None
 		project_object.form = None
 		project_object.thumbnailer = None
+
+		# check whether using binary or ascii file
+		
+		if project.file_type == "binary":
+			file_is_binary = True
+		else:
+			file_is_binary = False
 				
 		# serialize the project object
 		myFile = file(file_path, "wb")
-		pickle.dump(project_object, myFile, True)
+		pickle.dump(project_object, myFile, file_is_binary)
 		
 		# re-attach some variables (that aren't pickleable)
 		project_object.form = old_form
@@ -85,12 +93,14 @@ def save_project(project_object, file_path):
 		project_object.form.mnuClip1.project = project_object
 		project_object.form.mnuMarker1.project = project_object
 		project_object.form.mnuTransition1.project = project_object
+		project_object.form.mnuFadeSubMenu1.project = project_object
 		project_object.form.mnuAnimateSubMenu1.project = project_object
 		project_object.form.mnuPositionSubMenu1.project = project_object
 		
 		# disable save button on form
 		project_object.set_project_modified(is_modified=False, refresh_xml=True)
 		
+		# add project file to recent files
 		manager = gtk.recent_manager_get_default()
 		manager.add_item('file://' + file_path)
 		
