@@ -44,10 +44,11 @@ class sequence:
 		self.scale = 15.0		   # this represents how many seconds per tick mark
 		self.tick_pixels = 100	  # number of pixels between each tick mark
 		self.play_head_position = 0 # position of the play head in seconds
+		
 		# init the tracks on the sequence
 		self.tracks = []
-		self.tracks.append(track.track(_("Track 2"), self))
-		self.tracks.append(track.track(_("Track 1"), self))
+		self.tracks.append(track.track(_("Track %s") % 2, self))
+		self.tracks.append(track.track(_("Track %s") % 1, self))
 
 		# init markers
 		self.markers = []
@@ -75,7 +76,7 @@ class sequence:
 		self.reorder_markers()
 		
 		# mark project as modified
-		self.project.set_project_modified(is_modified=True, refresh_xml=True)
+		self.project.set_project_modified(is_modified=True, refresh_xml=True, type=_("Added marker"))
 		
 		return m
 
@@ -118,8 +119,6 @@ class sequence:
 		
 	def AddTrack(self, track_name, position="above", existing_track=None):
 		
-		# mark project as modified
-		self.project.set_project_modified(is_modified=True, refresh_xml=True)
 		
 		# Add another track
 		if existing_track:
@@ -134,12 +133,15 @@ class sequence:
 			# insert at top of tracks
 			self.tracks.insert(0, track.track(track_name, self))
 
+		# mark project as modified
+		self.project.set_project_modified(is_modified=True, refresh_xml=True, type=_("Added Track"))
+
 			
 	def rename_track(self, current_track, new_name):
 		current_track.name = new_name
 		
 		# mark project as modified
-		self.project.set_project_modified(is_modified=True, refresh_xml=True)
+		self.project.set_project_modified(is_modified=True, refresh_xml=True, type=_("Renamed track"))
 		
 			
 	def get_pixels_per_second(self):
@@ -192,24 +194,41 @@ class sequence:
 		bg_track.parent = self
 		bg_end_time = self.Calculate_Length()
 		bg_image = files.OpenShotFile(self.project)
-		#bg_image.name = "background_track"
 		bg_image.name = os.path.join(self.project.IMAGE_DIR, "black.png")
-		#bg_image.name = "/home/jonathan/Desktop/Temp OpenShot/background.png"
 		bg_image.length = bg_end_time
 		bg_image.max_frames = round(bg_end_time * fps)
-		bg_clip = clip.clip("Background Clip", "Gold", 0.0, 0.0, bg_end_time, bg_track, bg_image)
-		bg_clip.distort = True
-		bg_clip.fill = True
-		bg_track.clips.append(bg_clip)
+		
+		# set remaining length
+		remaining_length = bg_end_time
+		position = 0.0
+		current_length = 0.0
+		
+		# Add the background black clip in sections (5 minute (i.e. 300 seconds) sections)
+		while remaining_length > 0.0:
+			# calculate length of this section
+			if remaining_length > 300.0:
+				current_length = 300.0
+				remaining_length -= 300.0
+			else:
+				current_length = remaining_length
+				remaining_length = 0.0
+							
+			bg_clip = clip.clip("Background Clip", "Gold", position, 0.0, current_length, bg_track, bg_image)
+			bg_clip.distort = True
+			bg_clip.fill = True
+			bg_track.clips.append(bg_clip)
+			
+			# calculate position for next section
+			position += current_length
 		
 		# add XML for background track
-		bg_track.GenerateXML(dom, multitrack)
+		bg_track.GenerateXML(dom, multitrack, fps=fps)
 		
 		# loop through each track, from the bottom up
 		for MyTrack in reversed(self.tracks):
 			
 			# Render track			
-			MyTrack.GenerateXML(dom, multitrack)
+			MyTrack.GenerateXML(dom, multitrack, fps=fps)
 			
 
 	def Calculate_Length(self):
@@ -271,8 +290,8 @@ class sequence:
 		Size_Of_Middle = int(pixels_per_second * self.length)
 		
 		# resize the canvas height and width
-		canvas_right.set_bounds (0, 0, Size_Of_Middle + 200, 1000)
-		canvas_timeline.set_bounds (0, 0, Size_Of_Middle + 185, 1000)
+		canvas_right.set_bounds (0, 0, Size_Of_Middle + 200, 80)
+		canvas_timeline.set_bounds (0, 0, Size_Of_Middle + 185, 5000)
 		self.project.form.hscrollbar2.set_range(0, Size_Of_Middle + 200)
 		self.project.form.on_hscrollbar2_value_changed(self.project.form.hscrollbar2)
 
@@ -407,16 +426,17 @@ class sequence:
 			pixels_per_second = self.get_pixels_per_second()
 
 			# calculate playhead position
-			play_head_position = new_x / pixels_per_second
+			self.play_head_position = new_x / pixels_per_second
 			
-			if play_head_position < 0:
-				play_head_position = 0
+			if self.play_head_position < 0:
+				self.play_head_position = 0
 			
 			# move playhead
-			self.move_play_head(play_head_position)
+			self.project.form.MyVideo.move_play_head(self.play_head_position)
 			
 			# update video frame
 			self.update_video()
+
 			
 
 	def on_ruler_motion(self, item, target, event):
@@ -429,13 +449,13 @@ class sequence:
 			pixels_per_second = self.get_pixels_per_second()
 
 			# calculate playhead position
-			play_head_position = new_x / pixels_per_second
+			self.play_head_position = new_x / pixels_per_second
 			
-			if play_head_position < 0:
-				play_head_position = 0
+			if self.play_head_position < 0:
+				self.play_head_position = 0
 			
 			# move playhead
-			self.move_play_head(play_head_position)
+			self.project.form.MyVideo.move_play_head(self.play_head_position)
 			
 			# update video frame
 			self.update_video()
@@ -548,7 +568,6 @@ class sequence:
 		
 		
 	def on_motion_notify_x (self, item, target, event):
-		#print "on_motion_notify_x"
 		"""this method allows the clip to be dragged and dropped on a track"""
 
 		if (event.state & gtk.gdk.BUTTON1_MASK):
@@ -572,12 +591,6 @@ class sequence:
 			item.translate (total_x_diff, 0)
 			self.play_head_line.translate(total_x_diff, 0)
 
-			# print time of playhead
-			milliseconds = ((item.get_bounds().x1 + (playhead_width / 2)) / pixels_per_second) * 1000
-			time = timeline.timeline().get_friendly_time(milliseconds)
-			frame = round((time[5] / 1000.0) * self.project.fps()) + 1
-			self.ruler_time.set_property("text", "%02d:%02d:%02d:%02d" % (time[2], time[3], time[4], frame))
-
 			# update playhead position
 			self.play_head_position = (item.get_bounds().x1 + (playhead_width / 2)) / pixels_per_second
 			
@@ -596,10 +609,6 @@ class sequence:
 		# Refresh the MLT XML file
 		self.project.RefreshXML()
 		
-		# start and stop the video
-		self.project.form.MyVideo.play()
-		self.project.form.MyVideo.pause()
-		
 		# determine new frame number
 		frame = self.project.fps() * self.play_head_position
 		
@@ -612,7 +621,8 @@ class sequence:
 		a parameter for the # of seconds to move the playhead to."""
 		
 		# move play_head to the top layer
-		if self.play_head:
+		if self.play_head and new_time != self.play_head_position:
+
 			self.play_head.raise_(None)
 			self.play_head_line.raise_(None)
 			
@@ -635,10 +645,7 @@ class sequence:
 			time = timeline.timeline().get_friendly_time(milliseconds)
 			frame = round((time[5] / 1000.0) * self.project.fps()) + 1
 			self.ruler_time.set_property("text", "%02d:%02d:%02d:%02d" % (time[2], time[3], time[4], frame))
-			
-#			print "-----"
-#			print (milliseconds / 1000.0) * self.project.fps()
-#			print self.project.form.MyVideo.p.position()
+			#self.ruler_time.set_property("text", "%s" % (self.project.form.MyVideo.p.position()))
 			
 			# update playhead position
 			self.play_head_position = (self.play_head.get_bounds().x1 + (playhead_width / 2)) / pixels_per_second
@@ -647,6 +654,7 @@ class sequence:
 	
 	def on_button_press_x (self, item, target, event):
 		""" This method initializes some variables needed for dragging and dropping a clip """
+		
 		# raise the group up to the top level
 		item.raise_(None)
 
@@ -663,6 +671,9 @@ class sequence:
 								 gtk.gdk.POINTER_MOTION_MASK | gtk.gdk.BUTTON_RELEASE_MASK,
 								 fleur,
 								 event.time)
+			
+			# pause the video
+			self.project.form.MyVideo.pause()
 
 		return True
 	
