@@ -42,12 +42,6 @@ class transition:
 		self.mask_value = mask_value	# 0.0 to 1.0
 		
 		
-	def length(self):
-
-		# return length
-		return self.length
-	
-		
 	def Render(self, exiting_item=None, x_offset = 0):
 		
 		# init vars
@@ -197,6 +191,7 @@ class transition:
 		# only respond to the first mouse button
 		if event.button == 1:
 
+
 			# determine what cursor mode is enable (arrow, razor, snap, etc...)
 			(isArrow, isRazor, isSnap, isResize) = self.parent.parent.project.form.get_toolbar_options()
 			
@@ -206,6 +201,8 @@ class transition:
 				# change the cursor for the drag n drop operation
 				fleur = gtk.gdk.Cursor (gtk.gdk.FLEUR)
 				canvas = item.get_canvas ()
+				self.stored_x = item.get_bounds().x1
+				self.stored_y = item.get_bounds().y1
 				canvas.pointer_grab (item, gtk.gdk.POINTER_MOTION_MASK | gtk.gdk.BUTTON_RELEASE_MASK, fleur, event.time)
 			
 			# RESIZE MODE
@@ -214,7 +211,8 @@ class transition:
 				# remember the original length and position before resizing starts
 				self.original_length = self.length
 				self.original_start_pos = self.position_on_track
-
+				self.stored_x = item.get_bounds().x1
+				self.stored_y = item.get_bounds().y1
 
 			# SNAP MODE
 			elif isSnap:
@@ -373,6 +371,7 @@ class transition:
 	def on_button_release_x (self, item, target, event):
 		""" This method drops a clip, and snaps the clip to the nearest valid track """
 
+
 		# raise the play head to the top
 		self.parent.parent.play_head.raise_(None)
 		self.parent.parent.play_head_line.raise_(None)
@@ -415,12 +414,19 @@ class transition:
 			# move the clip object on the timeline to correct position (snapping to the y and x of the track)		
 			item.translate (distance_from_clip, bottom_y - item.get_bounds().y1)
 			
-			
 		# reset the cursor
 		self.parent.parent.project.form.MyCanvas.window.set_cursor(None)
 		
+		# check if clip has been really moved or not
+		if self.stored_x == item.get_bounds().x1 and self.stored_y == item.get_bounds().y1 and not isResize:
+			type_of_event = None
+		elif isResize:
+			type_of_event = _("Resized transition")
+		else:
+			type_of_event = _("Moved transition")
+		
 		# mark project as modified
-		self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True)
+		self.parent.parent.project.set_project_modified(is_modified=True, refresh_xml=True, type = type_of_event )
 		
 		
 	def get_valid_drop(self, x1, y1):
