@@ -21,6 +21,7 @@ import os,copy,time, gobject
 import gtk, gtk.glade
 from windows.SimpleGladeApp import SimpleGladeApp
 from classes import profiles, project, video
+from windows import preferences
 import AddEffect, TreeEffects
 
 # init the foreign language
@@ -39,6 +40,7 @@ class frmClipProperties(SimpleGladeApp):
 		self.project = project
 		self.current_clip = current_clip
 		self.current_clip_item = current_clip_item
+		self.restore_window_size()
 		self.frmClipProperties.show_all()
 
 		# Stop the video thread consumer
@@ -126,6 +128,30 @@ class frmClipProperties(SimpleGladeApp):
 		# so that the real project is refreshed... even if these 
 		# preview changes are not accepted
 		self.project.set_project_modified(is_modified=False, refresh_xml=True)
+
+		
+	def restore_window_size(self):
+		#default the form as not maximized
+		self.is_maximized = False
+		
+		#load the window settings
+		self.settings = preferences.Settings(self.project)
+		self.settings.load_settings_from_xml()
+			
+		#get the app state settings
+		self.width = int(self.settings.app_state["clip_property_window_width"])
+		self.height = int(self.settings.app_state["clip_property_window_height"])
+		is_max = self.settings.app_state["clip_property_window_maximized"]
+		
+		#resize window		
+		self.frmClipProperties.resize(self.width, self.height)
+		
+		#maximize window if needed
+		if is_max == "True":
+			self.frmClipProperties.maximize()
+		
+		#set pane size from config xml
+		self.hpaned1.set_position(int(self.settings.app_state["clip_property_hpane_position"]))
 		
 	def on_treeEffects_button_release_event(self, widget, *args):
 		print "on_treeEffects_button_release_event"
@@ -134,9 +160,9 @@ class frmClipProperties(SimpleGladeApp):
 		_ = self._
 		
 		# get selected effect (if any)
-		selected_effect = self.get_selected_effect()
+		selected_effect, unique_id = self.get_selected_effect()
 		real_effect = self.OSTreeEffects.get_real_effect(service=selected_effect)
-		clip_effect = self.get_clip_effect(service=selected_effect)
+		clip_effect = self.get_clip_effect(unique_id)
 		
 		if real_effect:
 			
@@ -155,13 +181,14 @@ class frmClipProperties(SimpleGladeApp):
 				
 				# update label with title
 				label.set_text(_(param.title))
+				label.set_tooltip_text(_(param.title))
 
 				if param.type == "spinner":
 					# create spinner
 					adj = gtk.Adjustment(float(user_param_value), float(param.min), float(param.max), 0.01, 0.01, 0.0)
 					spinner = gtk.SpinButton(adj, 0.01, 2)
 					# connect signal 
-					spinner.connect("value-changed", self.effect_spinner_changed, real_effect, param)
+					spinner.connect("value-changed", self.effect_spinner_changed, real_effect, param, unique_id)
 					# add to hbox
 					hbox.pack_start(spinner, expand=True, fill=True)
 				
@@ -180,7 +207,7 @@ class frmClipProperties(SimpleGladeApp):
 						box_index = box_index + 1
 						
 					# connect signal
-					cboBox.connect("changed", self.effect_dropdown_changed, real_effect, param)
+					cboBox.connect("changed", self.effect_dropdown_changed, real_effect, param, unique_id)
 					# add to hbox
 					hbox.pack_start(cboBox, expand=True, fill=True)
 					
@@ -191,7 +218,7 @@ class frmClipProperties(SimpleGladeApp):
 					colorButton.set_color(default_color)	
 
 					# connect signal
-					colorButton.connect("color-set", self.effect_color_changed, real_effect, param)
+					colorButton.connect("color-set", self.effect_color_changed, real_effect, param, unique_id)
 					# add to hbox
 					hbox.pack_start(colorButton, expand=True, fill=True)
 				
@@ -201,11 +228,11 @@ class frmClipProperties(SimpleGladeApp):
 				# increment param index
 				param_index = param_index + 1
 				
-	def get_clip_effect(self, service):
+	def get_clip_effect(self, unique_id):
 		""" find the effect object on the clip... that matches the service string. """
 		# Loop through all effects
 		for clip_effect in self.copy_of_clip.effects:
-			if clip_effect.service == service:
+			if clip_effect.unique_id == unique_id:
 				# Found clip effect... now we need to find the actual param to update
 				return clip_effect
 			
@@ -218,12 +245,12 @@ class frmClipProperties(SimpleGladeApp):
 				return clip_param[parameter_name]
 				
 				
-	def effect_spinner_changed(self, widget, real_effect, param, *args):
+	def effect_spinner_changed(self, widget, real_effect, param, unique_id, *args):
 		print "effect_spinner_changed"
 		
 		# Update the param of the selected effect
 		for clip_effect in self.copy_of_clip.effects:
-			if clip_effect.service == real_effect.service or clip_effect.service == real_effect.service + ":" + real_effect.audio_effect:
+			if clip_effect.unique_id == unique_id:
 				# Found clip effect... now we need to find the actual param to update
 				for clip_param in clip_effect.paramaters:
 					# find the matching param
@@ -232,7 +259,7 @@ class frmClipProperties(SimpleGladeApp):
 						clip_param[param.name] = str(widget.get_value())
 						return
 		
-	def effect_dropdown_changed(self, widget, real_effect, param, *args):
+	def effect_dropdown_changed(self, widget, real_effect, param, unique_id, *args):
 		print "effect_dropdown_changed"
 		
 		# find numeric value of dropdown selection
@@ -243,7 +270,7 @@ class frmClipProperties(SimpleGladeApp):
 		
 		# Update the param of the selected effect
 		for clip_effect in self.copy_of_clip.effects:
-			if clip_effect.service == real_effect.service or clip_effect.service == real_effect.service + ":" + real_effect.audio_effect:
+			if clip_effect.unique_id == unique_id:
 				# Found clip effect... now we need to find the actual param to update
 				for clip_param in clip_effect.paramaters:
 					# find the matching param
@@ -252,7 +279,7 @@ class frmClipProperties(SimpleGladeApp):
 						clip_param[param.name] = dropdown_value
 						return
 		
-	def effect_color_changed(self, widget, real_effect, param, *args):
+	def effect_color_changed(self, widget, real_effect, param, unique_id, *args):
 		print "effect_color_changed"
 		
 		# Get color from color picker
@@ -260,7 +287,7 @@ class frmClipProperties(SimpleGladeApp):
 
 		# Update the param of the selected effect
 		for clip_effect in self.copy_of_clip.effects:
-			if clip_effect.service == real_effect.service or clip_effect.service == real_effect.service + ":" + real_effect.audio_effect:
+			if clip_effect.unique_id == unique_id:
 				# Found clip effect... now we need to find the actual param to update
 				for clip_param in clip_effect.paramaters:
 					# find the matching param
@@ -306,13 +333,39 @@ class frmClipProperties(SimpleGladeApp):
 		for iter in iters:
 			Name_of_Effect = self.treeEffects.get_model().get_value(iter, 1)
 			Effect_Service = self.treeEffects.get_model().get_value(iter, 2)
-			return Effect_Service
+			unique_id = self.treeEffects.get_model().get_value(iter, 3)
+			return Effect_Service, unique_id
 		
 		# no selected item
-		return None
+		return None, None
+	
+		
+	def on_frmClipProperties_window_state_event(self, widget, event, *args):
+		# determine if properties window is maximized or not 
+		
+		if event.changed_mask & gtk.gdk.WINDOW_STATE_MAXIMIZED:
+			if event.new_window_state & gtk.gdk.WINDOW_STATE_MAXIMIZED:
+				# maximized
+				self.is_maximized = True
+			else:
+				# not maximized
+				self.is_maximized = False
+				
+		# refresh sdl on window resize
+		if self.form.MyVideo:
+			self.form.MyVideo.c.set("refresh", 1)
+
 		
 	def on_frmClipProperties_destroy(self, widget, *args):
-		print "on_frmClipProperties_destroy"
+		#print "on_frmClipProperties_destroy"
+		#get the property window size
+		self.settings.app_state["clip_property_window_maximized"] = str(self.is_maximized)
+		self.settings.app_state["clip_property_window_width"] = self.width
+		self.settings.app_state["clip_property_window_height"] = self.height
+		self.settings.app_state["clip_property_hpane_position"] = self.hpaned1.get_position()
+		
+		#save the settings
+		self.settings.save_settings_to_xml()
 		
 		
 	def on_frmClipProperties_close(self, widget, *args):
@@ -322,10 +375,21 @@ class frmClipProperties(SimpleGladeApp):
 		self.close_window()
 		
 		return True
+	
+	def on_frmClipProperties_configure_event(self, widget, *args):
+		print "on_frmClipProperties_configure_event"
+		
+		#handles the resize event of the window
+		#set the new width and height from the window resize
+		(self.width, self.height) = self.frmClipProperties.get_size()	
+
+		# refresh sdl on window resize
+		if self.form.MyVideo:
+			self.form.MyVideo.c.set("refresh", 1)
 		
 		
 	def on_btnAddEffect_clicked(self, widget, *args):
-		print "on_btnAddEffect_clicked"
+		#print "on_btnAddEffect_clicked"
 		
 		# show frmExportVideo dialog
 		self.frmAddEffect = AddEffect.frmAddEffect(parent=self, form=self.form, project=self.project)
@@ -338,41 +402,47 @@ class frmClipProperties(SimpleGladeApp):
 		print "on_btnRemoveEffect_clicked"
 		
 		# Get selected effect
-		selected_service = self.get_selected_effect()
-		self.copy_of_clip.Remove_Effect(selected_service)
+		selected_service, unique_id = self.get_selected_effect()
+		if selected_service:
+			# Remove effect
+			self.copy_of_clip.Remove_Effect(unique_id)
 		
-		# update effect tree
-		self.update_effects_tree()
-		
-		# clear effect controls
-		self.clear_effect_controls()
+			# update effect tree
+			self.update_effects_tree()
+			
+			# clear effect controls
+			self.clear_effect_controls()
 		
 		
 	def on_btnEffectUp_clicked(self, widget, *args):
 		print "on_btnEffectUp_clicked"
 		
 		# Get selected effect
-		selected_service = self.get_selected_effect()
-		self.copy_of_clip.Move_Effect(selected_service, "up")
-		
-		# update effect tree
-		self.update_effects_tree()
-		
-		# clear effect controls
-		self.clear_effect_controls()
+		selected_service, unique_id = self.get_selected_effect()
+		if selected_service:
+			# Move Effect
+			self.copy_of_clip.Move_Effect(unique_id, "up")
+			
+			# update effect tree
+			self.update_effects_tree()
+			
+			# clear effect controls
+			self.clear_effect_controls()
 	
 	def on_btnEffectDown_clicked(self, widget, *args):
 		print "on_btnEffectDown_clicked"
 		
 		# Get selected effect
-		selected_service = self.get_selected_effect()
-		self.copy_of_clip.Move_Effect(selected_service, "down")
-		
-		# update effect tree
-		self.update_effects_tree()
-		
-		# clear effect controls
-		self.clear_effect_controls()
+		selected_service, unique_id = self.get_selected_effect()
+		if selected_service:
+			# Move Effect
+			self.copy_of_clip.Move_Effect(unique_id, "down")
+			
+			# update effect tree
+			self.update_effects_tree()
+			
+			# clear effect controls
+			self.clear_effect_controls()
 
 	def on_btnResetVolume_clicked(self, widget, *args):
 		print "on_btnResetVolume_clicked"
@@ -727,9 +797,13 @@ class frmClipProperties(SimpleGladeApp):
 
 		# Get the current speed
 		current_speed = self.form.MyVideo.p.get_speed()
+		position = self.form.MyVideo.p.position()
 		
 		# Refresh Preview XML
 		self.RefreshPreview()
+		
+		# seek back to position
+		self.form.MyVideo.seek(position)
 
 		# is video stopped?
 		if current_speed == 0:
@@ -738,23 +812,42 @@ class frmClipProperties(SimpleGladeApp):
 		else:
 			# stop video
 			self.form.MyVideo.pause()
+			
 
+		
+		
+	def on_hpaned1_size_allocate(self, widget, *args):
+		#print "on_hpanel1_size_allocate"
+		
+		if self.form.MyVideo:
+			# refresh sdl
+			self.form.MyVideo.c.set("refresh", "1")
+			
 
 	def on_hsPreviewProgress_button_press_event(self, widget, *args):
-		print "on_hsPreviewProgress_button_press_event"
+		#print "on_hsPreviewProgress_button_press_event"
 		
+		# get the percentage of the video progress 0 to 100
+		video_progress_percent = float(self.hsPreviewProgress.get_value()) / 100.0
+
+		# determine frame number
+		new_frame = int(float(self.form.MyVideo.p.get_length() - 1) * video_progress_percent)
+
 		# Refresh Preview XML
 		self.RefreshPreview()
-		
 
-	def on_hsPreviewProgress_value_changed(self, widget, *args):
+		# jump to this frame
+		self.form.MyVideo.seek(new_frame)
+		
+		# start and stop the video
+		self.form.MyVideo.c.set("refresh", 1)
+
+
+	def on_hsPreviewProgress_change_value(self, widget, *args):
+		#print "on_hsPreviewProgress_value_changed"
 
 		# get the percentage of the video progress 0 to 100
 		video_progress_percent = float(self.hsPreviewProgress.get_value()) / 100.0
-		
-		# start and stop the video
-		self.form.MyVideo.play()
-		self.form.MyVideo.pause()
 
 		# determine frame number
 		new_frame = int(float(self.form.MyVideo.p.get_length() - 1) * video_progress_percent)
@@ -762,19 +855,22 @@ class frmClipProperties(SimpleGladeApp):
 		# jump to this frame
 		self.form.MyVideo.p.seek(new_frame)
 		
+		# start and stop the video
+		self.form.MyVideo.c.set("refresh", 1)
+		
 	def RefreshPreview(self):
 		# Apply settings to preview clip object
 		self.apply_settings(self.copy_of_clip)
 
 		# Generate the Preview XML
-		self.copy_of_clip.GeneratePreviewXML(os.path.join(self.project.USER_DIR, "preview_clip.xml"))
+		self.copy_of_clip.GeneratePreviewXML(os.path.join(self.project.USER_DIR, "preview.mlt"))
 
 		# Hook up video thread to new alternative progress bar
 		#self.form.MyVideo.alternate_progress_bar = self.hsPreviewProgress
 		gobject.idle_add(self.form.MyVideo.set_progress_bar, self.hsPreviewProgress)
 
 		# Load XML
-		self.form.MyVideo.set_project(self.project, self.form, os.path.join(self.project.USER_DIR, "preview_clip.xml"), mode="preview")
+		self.form.MyVideo.set_project(self.project, self.form, os.path.join(self.project.USER_DIR, "preview.mlt"), mode="preview")
 		self.form.MyVideo.load_xml()
 
 
@@ -798,7 +894,7 @@ class frmClipProperties(SimpleGladeApp):
 			self.current_clip.effects = copy.deepcopy(self.copy_of_clip.effects)
 			
 			# mark project as modified
-			self.project.set_project_modified(is_modified=True, refresh_xml=True)
+			self.project.set_project_modified(is_modified=True, refresh_xml=True, type = self._("Modified clip properties"))
 			
 			# remove from canvas
 			parent = self.current_clip_item.get_parent()
