@@ -16,13 +16,20 @@
 #	You should have received a copy of the GNU General Public License
 #	along with OpenShot Video Editor.  If not, see <http://www.gnu.org/licenses/>.
 
+has_py_notify = False
 
+try:
+	import pynotify
+	has_py_notify = True
+except:
+	has_py_notify = False
+		
 import os
 import gtk, gtk.glade
 import xml.dom.minidom as xml
+import locale
 
 from classes import messagebox, profiles, project, video
-
 from windows.SimpleGladeApp import SimpleGladeApp
 
 # init the foreign language
@@ -42,6 +49,8 @@ class frmExportVideo(SimpleGladeApp):
 		self.project = project
 		self.frmExportVideo.show_all()
 		
+		self.invalid_codecs = []
+		
 		# init the project type properties
 		self.init_properties(self.cmbProjectType.get_active_text())
 		
@@ -71,6 +80,29 @@ class frmExportVideo(SimpleGladeApp):
 			# append profile to list
 			self.cboExportTo.append_text(option)
 			
+		#populate the format/codec drop downs 
+		#formats
+		format_model = self.cboVIdeoFormat.get_model()
+		format_model.clear()
+		
+		for format in self.form.vformats:
+			self.cboVIdeoFormat.append_text(format)
+			
+		#video codecs
+		vcodecs_model = self.cboVideoCodec.get_model()
+		vcodecs_model.clear()
+		
+		for vcodec in self.form.vcodecs:
+			self.cboVideoCodec.append_text(vcodec)
+			
+		#audio codecs
+		acodecs_model = self.cboAudioCodec.get_model()
+		acodecs_model.clear()
+		
+		for acodec in self.form.acodecs:
+			self.cboAudioCodec.append_text(acodec)
+			
+			
 		# set the dropdown boxes
 		self.set_project_type_dropdown()
 		self.set_export_to_dropdown()
@@ -85,7 +117,9 @@ class frmExportVideo(SimpleGladeApp):
 		presets = list(set(presets))
 		for item in sorted(presets):
 			self.cboSimpleProjectType.append_text(item)
-		
+		#indicate that exporting cancelled
+		self.cancelled = False
+
 		
 	def set_project_type_dropdown(self):
 		
@@ -112,6 +146,12 @@ class frmExportVideo(SimpleGladeApp):
 			if iter is None:
 				break
 			
+	def on_expander_activate(self, widget, *args):
+		#print "on_expander_activate"
+		#self.frmExportVideo.set_size_request(0,0)
+		pass
+		
+			
 	def set_selection_dropdown(self):
 		
 		# get reference to gettext
@@ -238,7 +278,7 @@ class frmExportVideo(SimpleGladeApp):
 				self.cboSimpleVideoProfile.append_text(item)
 				
 			# choose the default project type / profile (if it's listed)
-			self.set_dropdown_values(self.project.project_type, self.cboSimpleVideoProfile)
+			#self.set_dropdown_values(self.project.project_type, self.cboSimpleVideoProfile)
 
 			#set the quality combo
 			#only populate with quality settings that exist
@@ -278,8 +318,11 @@ class frmExportVideo(SimpleGladeApp):
 		#don't do anything if the combo has been cleared
 		if self.cboSimpleQuality.get_active_text():
 		
-			quality = str(self.cboSimpleQuality.get_active_text())
+			# reset the invalid codecs list
+			self.invalid_codecs = []
 			
+			# Get the quality
+			quality = str(self.cboSimpleQuality.get_active_text())
 			
 			#set the attributes in the advanced tab
 			#video format
@@ -304,6 +347,16 @@ class frmExportVideo(SimpleGladeApp):
 			#audio bit rate
 			self.cboAudioBitRate.insert_text(0,self.abr[quality])
 			self.cboAudioBitRate.set_active(0)
+			
+			#check for any invalid codecs and disable
+			#the export button if required.
+			if self.invalid_codecs:
+				missing_codecs = ""
+				for codec in self.invalid_codecs:
+					missing_codecs += codec + "\n"
+					
+				messagebox.show(_("Openshot Error"), _("The following formats/codecs are missing from your system:" + "\n\n" + "%s" % missing_codecs + "\nYou will not be able to use the selected export profile.  You will need to install the missing formats/codecs or choose a different export profile."))
+				self.btnExportVideo.set_sensitive(False)
 		
 			
 	def set_dropdown_values(self, value_to_set, combobox):
@@ -328,8 +381,8 @@ class frmExportVideo(SimpleGladeApp):
 			iter = model.iter_next(iter)
 			
 			# break loop when no more dropdown items are found
-			if iter is None:
-				#messagebox.show(_"Error"),_("No
+			if iter is None and value_to_set not in self.invalid_codecs:
+				self.invalid_codecs.append(value_to_set)
 				break
 
 	def init_properties(self, profile):
@@ -363,10 +416,14 @@ class frmExportVideo(SimpleGladeApp):
 		
 	def on_frmExportVideo_destroy(self, widget, *args):
 		print "on_frmExportVideo_destroy"
+		self.cancelled = True
 		
 		# stop the export (if in-progress)
 		if self.project.form.MyVideo:
 			self.project.form.MyVideo.c.stop()
+			
+		# mark project as modified
+		self.project.set_project_modified(is_modified=True, refresh_xml=True)
 
 		
 	def on_cboExportTo_changed(self, widget, *args):
@@ -409,6 +466,7 @@ class frmExportVideo(SimpleGladeApp):
 		
 	def on_btnCancel_clicked(self, widget, *args):
 		print "on_btnCancel_clicked"
+		self.cancelled=True
 		self.frmExportVideo.destroy()
 		
 	def on_btnExportVideo_clicked(self, widget, *args):
@@ -429,13 +487,13 @@ class frmExportVideo(SimpleGladeApp):
 		localtxtImageFormat = str.strip(self.txtImageFormat.get_text())
 		
 		# get video settings
-		localtxtVideoFormat = str.strip(self.txtVideoFormat.get_text())
-		localtxtVideoCodec = str.strip(self.txtVideoCodec.get_text())
+		localtxtVideoFormat = self.cboVIdeoFormat.get_active_text()
+		localtxtVideoCodec = self.cboVideoCodec.get_active_text()
 		localtxtBitRate = str.strip(self.txtBitRate.get_text())
 		BitRateBytes = self.convert_to_bytes(localtxtBitRate)
 
 		# get audio settings
-		localtxtAudioCodec = str.strip(self.txtAudioCodec.get_text())
+		localtxtAudioCodec = self.cboAudioCodec.get_active_text()
 		localtxtSampleRate = str.strip(self.txtSampleRate.get_text())
 		localtxtChannels = str.strip(self.txtChannels.get_text())
 		localtxtAudioBitRate = str.strip(self.txtAudioBitRate.get_text())
@@ -496,7 +554,7 @@ class frmExportVideo(SimpleGladeApp):
 			
 		else:
 			# VALID FORM
-			
+					
 			# update the project's profile
 			self.project.project_type = localcmbProjectType
 
@@ -504,44 +562,55 @@ class frmExportVideo(SimpleGladeApp):
 			self.project.RefreshXML()
 			
 			# create dictionary of all options
-			render_options = {}
-			render_options["folder"] = localfileExportFolder
-			render_options["file"] = localtxtFileName
-			render_options["export_to"] = localcboExportTo
+			self.render_options = {}
+			self.render_options["folder"] = localfileExportFolder
+			self.render_options["file"] = localtxtFileName
+			self.render_options["export_to"] = localcboExportTo
 			
 			if localcboExportTo == _("Image Sequence"):
-				render_options["vcodec"] = localtxtImageFormat
-				render_options["f"] = localtxtImageFormat
+				self.render_options["vcodec"] = localtxtImageFormat
+				self.render_options["f"] = localtxtImageFormat
 				
 			elif localcboExportTo == _("Video & Audio"):
-				render_options["vcodec"] = localtxtVideoCodec
-				render_options["f"] = localtxtVideoFormat
+				self.render_options["vcodec"] = localtxtVideoCodec
+				self.render_options["f"] = localtxtVideoFormat
 				
-			render_options["b"] = BitRateBytes
-			render_options["acodec"] = localtxtAudioCodec
-			render_options["ar"] = localtxtSampleRate
-			render_options["ac"] = localtxtChannels
-			render_options["ab"] = AudioBitRateBytes
+			self.render_options["b"] = BitRateBytes
+			self.render_options["acodec"] = localtxtAudioCodec
+			self.render_options["ar"] = localtxtSampleRate
+			self.render_options["ac"] = localtxtChannels
+			self.render_options["ab"] = AudioBitRateBytes
 
 			# get the complete path to the new file
-			folder1 = render_options["folder"]
-			file1 = render_options["file"]
-			self.export_path = "%s.%s" % (os.path.join(folder1, file1), render_options["f"])
+			folder1 = self.render_options["folder"]
+			file1 = self.render_options["file"]
+			self.export_path = "%s.%s" % (os.path.join(folder1, file1), self.render_options["f"])
 
-			# flag that an export is in-progress
-			self.export_in_progress = True
-			# set window as MODAL (so they can't mess up the export)
-			self.frmExportVideo.set_modal(True)
-			
-			# re-load the xml
-			self.project.form.MyVideo.set_profile(localcmbProjectType, load_xml=False)
-			self.project.form.MyVideo.set_project(self.project, self.project.form, os.path.join(self.project.USER_DIR, "westley.xml"), mode="render", render_options=render_options)
-			self.project.form.MyVideo.load_xml()
-			
-			# mark project as modified
-			self.project.set_project_modified(is_modified=False, refresh_xml=True)
+			#check for existing filename before export and confirm overwrite
+			if os.path.exists(self.export_path):
+				messagebox.show(_("Confirm Overwrite"), _("There is already a video file named %s.%s in the selected export folder. Would you like to overwrite it?") % (file1, self.render_options["f"]), gtk.BUTTONS_YES_NO, self.confirm_overwrite_yes)
+			else:
+				# no existing file, so export now
+				self.do_export()
+			     	
+		
+			 
+	def do_export(self):
+		render_options = self.render_options
+		# flag that an export is in-progress
+		self.export_in_progress = True
+		# set window as MODAL (so they can't mess up the export)
+		self.frmExportVideo.set_modal(True)
+		
+		# re-load the xml
+		self.project.form.MyVideo.set_profile(self.project.project_type, load_xml=False)
+		self.project.form.MyVideo.set_project(self.project, self.project.form, os.path.join(self.project.USER_DIR, "sequence.mlt"), mode="render", render_options=render_options)
+		self.project.form.MyVideo.load_xml()
+		
 
-			
+	def confirm_overwrite_yes(self):
+		#user agrees to overwrite the file
+		self.do_export()
 			
 	def update_progress(self, new_percentage):
 		
@@ -556,9 +625,19 @@ class frmExportVideo(SimpleGladeApp):
 			
 			# remove the MODAL property from the window (sicne we are done)
 			self.frmExportVideo.set_modal(False)
-
-			# prompt user that export is completed
-			messagebox.show(_("Export Complete"), _("The video has been successfully exported to\n%s" % self.export_path))
+			if not self.cancelled:
+				title = _("Export Complete")
+				message = _("The video has been successfully exported to\n%s") % self.export_path
+				
+				# prompt user that export is completed
+				if has_py_notify:
+					# Use libnotify to show the message (if possible)
+					if pynotify.init("OpenShot Video Editor"):
+						n = pynotify.Notification(title, message)
+						n.show()
+				else:
+					# use a GTK messagebox
+					messagebox.show(title, message)
 			
 			# flag export as completed
 			self.export_in_progress = False
@@ -577,26 +656,40 @@ class frmExportVideo(SimpleGladeApp):
 		try:
 			# Get Bit Rate
 			if len(s) >= 2:
-				raw_number = float(s[0])
+				raw_number_string = s[0]
 				raw_measurement = s[1]
-				
+
+				# convert string number to float (based on locale settings)
+				raw_number = locale.atof(raw_number_string)
+
 				if "kb" in raw_measurement:
 					measurement = "kb"
-					#bit_rate_bytes = raw_number * 1024.0
 					bit_rate_bytes = raw_number * 1000.0
 					
 				elif "mb" in raw_measurement:
 					measurement = "mb"
-					#bit_rate_bytes = raw_number * 1024.0 * 1024.0
 					bit_rate_bytes = raw_number * 1000.0 * 1000.0
 					
 		except:
 			pass
-			
-			
+
 		# return the bit rate in bytes
 		return str(int(bit_rate_bytes))
 	
+	def on_cboVIdeoFormat_changed(self, widget, *args):
+		
+		self.btnExportVideo.set_sensitive(True)
+		
+	
+	def on_cboVideoCodec_changed(self, widget, *args):
+		
+		self.btnExportVideo.set_sensitive(True)
+		
+	
+	def on_cboAudioCodec_changed(self, widget, *args):
+		
+		self.btnExportVideo.set_sensitive(True)
+	
 			
 def main():
 	frmExportVideo1 = frmExportVideo()
