@@ -174,6 +174,12 @@ class frmNewProject(SimpleGladeApp):
 				self.project = project.project()
 				self.project.form = self.form
 				self.project.form.project = self.project
+				
+				# clear history (since we are opening a new project)
+				self.project.form.history_stack = []
+				self.project.form.history_index = -1
+				self.project.form.refresh_history()
+				self.project.set_project_modified(is_modified=True, refresh_xml=False, type=_("New project"))
 			
 			# set the project properties
 			self.project.name = localName
@@ -186,7 +192,7 @@ class frmNewProject(SimpleGladeApp):
 			self.project.form.MyVideo.pause()
 
 			# set the profile settings in the video thread
-			self.project.form.MyVideo.set_project(self.project, self.project.form, os.path.join(self.project.USER_DIR, "westley.xml"), mode="preview")
+			self.project.form.MyVideo.set_project(self.project, self.project.form, os.path.join(self.project.USER_DIR, "sequence.mlt"), mode="preview")
 			self.project.form.MyVideo.set_profile(localType)
 			self.project.form.MyVideo.load_xml()
 
