@@ -27,6 +27,7 @@
 ####################################################################################
 
 import os, sys
+import fnmatch
 import gtk, gtk.glade
 from xml.dom import minidom
 from classes import files, messagebox, project, profiles
@@ -41,7 +42,7 @@ import language.Language_Init as Language_Init
 
 class frmNewTitle(SimpleGladeApp):
 
-	def __init__(self, path="titles.glade", root="frmTitles", domain="OpenShot", form=None, project=None, **kwargs):
+	def __init__(self, path="titles.glade", root="frmTitles", domain="OpenShot", form=None, project=None, file=None, **kwargs):
 		SimpleGladeApp.__init__(self, os.path.join(project.GLADE_DIR, path), root, domain, **kwargs)
 
 		# Add language support
@@ -49,6 +50,7 @@ class frmNewTitle(SimpleGladeApp):
 
 		self.project = project
 		self.form = form
+		self.file = file
 
 		#find path where openshot is running
 		self.path = self.project.BASE_DIR
@@ -88,17 +90,43 @@ class frmNewTitle(SimpleGladeApp):
 		self.template_dir = os.path.join(self.path, "openshot", "titles", self.ratio_folder)
 		for file in sorted(os.listdir(self.template_dir)):
 			#pretty up the filename for display purposes
-			(fileName, fileExtension)=os.path.splitext(file)
+			if fnmatch.fnmatch(file, '*.svg'):
+				(fileName, fileExtension)=os.path.splitext(file)
 			self.cmbTemplate.append_text(fileName.replace("_"," "))
 
 		#add the changed event once the combo has been populated
 		self.cmbTemplate.connect("changed", self.on_cmbTemplate_changed)
 
-		self.cmbTemplate.grab_focus()
-		
-		
-		# init dropdown
-		self.set_template_dropdown()
+		if not self.file:
+			self.cmbTemplate.grab_focus()
+			# init dropdown
+			self.set_template_dropdown()
+		else:
+			self.filename = self.file
+			self.load_svg_template(self.file)
+			#set edit button states
+			self.btnEditText.set_sensitive(True)
+			self.btnFont.set_sensitive(True)
+			self.btnFontColor.set_sensitive(True)
+			self.btnBackgroundColor.set_sensitive(True)
+			self.btnAdvanced.set_sensitive(True)
+			self.writeToFile(self.xmldoc)
+			#show the text editor
+			#if self.noTitles == False:
+			#	self.on_btnEditText_clicked(widget)
+			#preview the file
+			self.set_img_pixbuf(self.filename)
+			
+			self.on_btnEditText_clicked(None)
+			
+			#turn off the create button once we have created the new file
+			self.btnCreate.set_sensitive(False)
+			self.cmbTemplate.set_sensitive(False)
+			
+			if self.noTitles == True:
+				self.btnEditText.set_sensitive(False)
+				self.btnFont.set_sensitive(False)
+				self.btnFontColor.set_sensitive(False)
 		
 		
 	def set_template_dropdown(self):
@@ -113,10 +141,6 @@ class frmNewTitle(SimpleGladeApp):
 
 
 	def on_btnCreate_clicked(self,widget):
-		#index 0 is the <select a template> entry
-#		if self.cmbTemplate.get_active() == 0:
-#			return
-#		else:
 		#prompt the user for a file name
 		self.filename = self.setTitleName()
 		if self.filename == "":
@@ -128,17 +152,17 @@ class frmNewTitle(SimpleGladeApp):
 		#set the new filename
 		(fileBaseName, fileExtension)=os.path.splitext(self.template_name)
 		self.filename = self.filename + fileExtension
+		#write the new file
+		self.writeToFile(self.xmldoc)
+		#show the text editor
+		if self.noTitles == False:
+			if not self.on_btnEditText_clicked(widget): return
 		#set edit button states
 		self.btnEditText.set_sensitive(True)
 		self.btnFont.set_sensitive(True)
 		self.btnFontColor.set_sensitive(True)
 		self.btnBackgroundColor.set_sensitive(True)
 		self.btnAdvanced.set_sensitive(True)
-		#write the new file
-		self.writeToFile(self.xmldoc)
-		#show the text editor
-		if self.noTitles == False:
-			self.on_btnEditText_clicked(widget)
 		#preview the file
 		self.set_img_pixbuf(self.filename)
 		
@@ -171,21 +195,22 @@ class frmNewTitle(SimpleGladeApp):
 		dialog.set_markup(_('Please enter a name for the new Title file:'))  
 		#create the text input field  
 		entry = gtk.Entry()  
+		entry.set_text(_("New Title"))
 		#allow the user to press enter as well as the OK button
 		entry.connect("activate", self.ShowInputDialog, dialog, gtk.RESPONSE_OK)  
 		hbox = gtk.HBox()  
 		hbox.pack_start(gtk.Label("Name:"), False, 5, 5)  
 		hbox.pack_end(entry)  
-		#some secondary text  
-		dialog.format_secondary_markup(_("<i>Only enter the name, not a file extension.</i>"))  
 		#add it and show it  
 		dialog.vbox.pack_end(hbox, True, True, 0)  
 		dialog.show_all()  
 		#show the dialog  
-		dialog.run()  
-		text = entry.get_text()
-		dialog.destroy()  
-		return text 
+		if dialog.run() == gtk.RESPONSE_OK:
+			text = entry.get_text()
+		else: 
+			text = ''
+		dialog.destroy()
+		return text
 
 	def ShowInputDialog(self,entry, dialog, response):  
 		dialog.response(response)    
@@ -251,6 +276,7 @@ class frmNewTitle(SimpleGladeApp):
 		
 		#import the file to the project.
 		self.project.project_folder.AddFile(self.filename)
+		self.project.thumbnailer.get_thumb_at_frame(self.filename)
 		self.frmTitles.destroy()
 		# refresh the main form
 		self.form.refresh()
@@ -356,10 +382,6 @@ class frmNewTitle(SimpleGladeApp):
 		# Loop through each TEXT element
 		for text_child in self.text_node:
 			
-			# get text in SVG
-			#if len(tspans[i].childNodes) > 0:
-			#	SVG_Text = tspans[i].childNodes[0].data
-		
 			# SET TEXT PROPERTIES
 			s = text_child.attributes["style"].value
 			#split the text node so we can access each part
@@ -402,22 +424,6 @@ class frmNewTitle(SimpleGladeApp):
 
 	def set_title_text(self):
 		'''sets the title and subtitle text'''    
-		#get the child node that contains the text.
-#		reflist = self.xmldoc.getElementsByTagName('tspan')[0]
-#		reflist_child = self.xmldoc.getElementsByTagName('tspan')[0].childNodes[0]
-#		#create a new node with the new title text.        
-#		if self.new_title_text:  
-#			#replace the original text with the user entered text.
-#			ptitle = self.xmldoc.createTextNode(self.new_title_text)
-#			reflist.replaceChild(ptitle,reflist_child)
-#		#set the sub-title, if the template contains one.     
-#		if self.subTitle == True:
-#			sub = self.xmldoc.getElementsByTagName('tspan')[1]
-#			sub_child = self.xmldoc.getElementsByTagName('tspan')[1].childNodes[0]
-#			if self.sub_title_text:
-#				#replace the original text with the user entered text.
-#				ptitle = self.xmldoc.createTextNode(self.sub_title_text)
-#				sub.replaceChild(ptitle,sub_child)
 		#write the file and preview the image 
 		self.writeToFile(self.xmldoc)
 		self.set_img_pixbuf(self.filename)
@@ -446,6 +452,8 @@ class frmNewTitle(SimpleGladeApp):
 	def on_btnEditText_clicked(self, widget):
 		#just show the text editor window.        
 		frm = frmEditText(self, number_of_text_boxes=self.text_fields, tspans=self.tspan_node, project=self.project)
+		frm.frmEditText.run()
+		return frm.accepted
 
 
 	def html_color(self, color):
@@ -493,6 +501,7 @@ class frmEditText(SimpleGladeApp):
 		self.frmTitles = instance
 		self.tspans = tspans
 		self.number_of_text_boxes = number_of_text_boxes
+		self.accepted = False
 
 		for i in range(0, self.number_of_text_boxes):
 			# get text in SVG
@@ -512,7 +521,7 @@ class frmEditText(SimpleGladeApp):
 		
 		for i in range(0, self.number_of_text_boxes):
 			# get textbox
-			tbox = self.vbox3.children()[i]
+			tbox = self.vbox3.get_children()[i]
 			tbox_text = tbox.get_text()
 
 			# update the SVG file
@@ -528,6 +537,7 @@ class frmEditText(SimpleGladeApp):
 
 		self.frmEditText.destroy()
 		self.frmTitles.set_title_text()
+		self.accepted = True
 
 
 	def on_btnCancel_clicked(self, widget):
