@@ -21,7 +21,7 @@ import os
 import gtk, gtk.glade
 import xml.dom.minidom as xml
 
-from classes import profiles, project, messagebox
+from classes import profiles, project, messagebox, tree
 from windows.SimpleGladeApp import SimpleGladeApp
 from xdg.IconTheme import *
 
@@ -49,13 +49,17 @@ class PreferencesMgr(SimpleGladeApp):
 		self.model = gtk.ListStore(str, gtk.gdk.Pixbuf)
 		
 		#Populate the form with the preference category icons
-		#There is only one category at the moment
+		#General section
 		pixbuf = view.render_icon(gtk.STOCK_PREFERENCES, size=gtk.ICON_SIZE_BUTTON, detail = None)
 		self.model.append([_('General'), pixbuf])
 		
-		#This would add another category called 'Audio'
-		#pixbuf = view.render_icon(gtk.STOCK_EDIT, size=gtk.ICON_SIZE_BUTTON, detail = None)
-		#self.model.append(['Audio', pixbuf])
+		#Formats section
+		pixbuf = view.render_icon(gtk.STOCK_INFO, size=gtk.ICON_SIZE_BUTTON, detail = None)
+		self.model.append([_('AV Formats'), pixbuf])
+		
+		#Formats section
+		pixbuf = view.render_icon(gtk.STOCK_INFO, size=gtk.ICON_SIZE_BUTTON, detail = None)
+		self.model.append([_('Profiles'), pixbuf])
 		
 				
 		# Connect the iconview with the model
@@ -77,17 +81,78 @@ class PreferencesMgr(SimpleGladeApp):
 		for dir in os.listdir(self.project.THEMES_DIR):
 			self.cmbThemes.append_text(dir)
 			
+		# populate project file type combo
+		for file_type in ["binary", "ascii"]:
+			self.cmbFileType.append_text(file_type)
+			
+			
+		#populate the codecs & formats
+		
+		self.VCodecList = gtk.ListStore(str)
+		self.tvVCodecs.set_model(self.VCodecList)
+		tree.treeviewAddGeneralTextColumn(self.tvVCodecs,_('Video Codecs'),0)
+		
+		self.ACodecList = gtk.ListStore(str)
+		self.tvACodecs.set_model(self.ACodecList)
+		tree.treeviewAddGeneralTextColumn(self.tvACodecs,_('Audio Codecs'),0)
+		
+		self.FormatsList = gtk.ListStore(str)
+		self.tvFormats.set_model(self.FormatsList)
+		tree.treeviewAddGeneralTextColumn(self.tvFormats,_('Formats'),0)	
+		
+		self.populate_codecs()
+		
+			
 		#populate form objects
 		self.txtImageLength.set_text(self.settings.general["imported_image_length"])
+		self.txtHistoryStackSize.set_text(self.settings.general["max_history_size"])
+		self.txtMeltCommandName.set_text(self.settings.general["melt_command"])		
 		theme_name = self.settings.general["default_theme"]
+		file_type = self.settings.general["project_file_type"]
 		self.set_dropdown_values(theme_name, self.cmbThemes)
 		self.set_dropdown_values(self.settings.general["default_profile"], self.cmbProfiles)
+		self.set_dropdown_values(file_type, self.cmbFileType)
 		#set the example theme icon
 		self.load_theme_image(theme_name)
 		
 		#show the form
 		self.frmPreferences.show_all()
 		
+	def populate_codecs(self):
+		
+		#populate the codecs
+		
+		#video codecs		
+		for codec in self.form.vcodecs:
+			self.VCodecList.append([codec])
+		
+		#audio codecs
+		for acodec in self.form.acodecs:
+			self.ACodecList.append([acodec])
+		
+		#formats
+		for format in self.form.vformats:
+			self.FormatsList.append([format])
+			
+	
+	def on_btnReload_clicked(self, widget, *args):
+		
+		#clear the codecs from the form object
+		#and repopulate the listviews
+		
+		self.VCodecList.clear()
+		self.ACodecList.clear()
+		self.FormatsList.clear()
+		
+		self.form.vcodecs[:] = []
+		self.form.acodecs[:] = []
+		self.form.vformats[:] = []
+		
+		melt_command = self.settings.general["melt_command"]
+		self.form.get_avformats(melt_command)
+		
+		self.populate_codecs()
+		
 		
 	def on_btnCancel_clicked(self, widget, *args):
 		self.frmPreferences.destroy()
@@ -98,7 +163,10 @@ class PreferencesMgr(SimpleGladeApp):
 		self.settings.general["imported_image_length"] = self.txtImageLength.get_text()
 		self.settings.general["default_theme"] = self.cmbThemes.get_active_text()
 		self.settings.general["default_profile"] = self.cmbProfiles.get_active_text()
-		
+		self.settings.general["project_file_type"] = self.cmbFileType.get_active_text()
+		self.settings.general["max_history_size"] = self.txtHistoryStackSize.get_text()
+		self.settings.general["melt_command"] = self.txtMeltCommandName.get_text()
+
 		# save settings
 		self.settings.save_settings_to_xml()
 		
@@ -124,18 +192,28 @@ class PreferencesMgr(SimpleGladeApp):
 		
 		
 	def on_icvCategories_selection_changed(self, icon_view, model=None):
+		
+		_ = self._
+		
 		#sets the notebook page to view depending
 		#on which category icon is selected.
 		selected = icon_view.get_selected_items()
 		if len(selected) == 0: return
 		i = selected[0][0]
 		category = self.model[i][0]
-		if category == "General":
+		if category == _("General"):
 			self.nbPrefPages.set_current_page(0)
 		#When adding extra categories,
-		#include them in this 'If' statement e.g.
-		#elif category == "Audio":
-		#	self.nbPrefPages.set_current_page(1)
+		#include them in this 'If' statement
+		elif category == _("AV Formats"):
+			self.nbPrefPages.set_current_page(1)
+		elif category == _("Profiles"):
+			self.nbPrefPages.set_current_page(2)
+			
+	def on_btnManageProfiles_clicked(self, widget, *args):
+		print "on_btnManageProfiles_clicked"
+		from windows import Profiles
+		Profiles.frmProfilesManager(form=self.form, project=self.project)
 			
 	
 	def set_dropdown_values(self, value_to_set, combobox):
@@ -172,7 +250,10 @@ class Settings:
 	general = {
 		"imported_image_length" : "7",
 		"default_theme" : "blue_glass",
-		"default_profile" : "DV NTSC"
+		"default_profile" : "DV NTSC",
+		"project_file_type" : "binary",
+		"max_history_size" : "20",
+		"melt_command" : "melt",
 		}
 	
 	app_state = {
@@ -182,7 +263,12 @@ class Settings:
 		"import_folder" : "None",
 		"toolbar_visible" : "True",
 		"vpane_position" : "370",
-		"hpane_position" : "450"
+		"hpane_position" : "450",
+		"clip_property_window_width" : "635",
+		"clip_property_window_height" : "345",
+		"clip_property_window_maximized" : "False",
+		"clip_property_hpane_position" : "260",
+		
 		}
 	
 	sections = {
@@ -205,7 +291,13 @@ class Settings:
 		
 		#Load the settings from the config file, if it exists
 		if os.path.exists(settings_path):
-			xmldoc = xml.parse(settings_path)
+			
+			try:
+				xmldoc = xml.parse(settings_path)
+			except xml.xml.parsers.expat.ExpatError:
+				# Invalid or empty config file
+				self.save_settings_to_xml()
+				return
 			#loop through each settings section and load the values
 			#into the relevant dictionary
 			for section, section_dict in self.sections.iteritems():
@@ -230,14 +322,24 @@ class Settings:
 			# no config file found, create one
 			self.save_settings_to_xml()
 			
-
-	
 	def save_settings_to_xml(self):
 		settings_path = os.path.join(self.project.USER_DIR, "config.xml")
 		
 		#update each xml element with the current dictionary values
 		if os.path.exists(settings_path):
-			xmldoc = xml.parse(settings_path)
+			try:
+				xmldoc = xml.parse(settings_path)
+			except xml.xml.parsers.expat.ExpatError:
+				# Invalid or empty config file, create new blank dom
+				messagebox.show(_("OpenShot Warning"), _("Invalid or empty preferences file found, loaded default values"))
+				xmldoc = xml.Document()
+				root_node = xmldoc.createElement("settings")
+				xmldoc.appendChild(root_node)
+				
+				# create a node for each section
+				for section, section_dict in self.sections.iteritems():
+					section_node = xmldoc.createElement(section)
+					root_node.appendChild(section_node)
 		else:
 			# missing config file, create new blank dom
 			xmldoc = xml.Document()
